@@ -2,7 +2,6 @@ import argparse
 import sys
 import concurrent.futures
 from collections import namedtuple
-from os import name
 from pathlib import Path
 from typing import List
 
@@ -55,20 +54,27 @@ def get_files(folder: str) -> List[str]:
     return [path.as_posix() for path in p.glob("**/*.sql")]
 
 
-def output_results(results: List[QueryResult]) -> None:
+def output_results(results: List[QueryResult], verbose: bool) -> None:
     """
     Output the results to the console (stdout).
 
     :param results: List of QueryResult named tuples.
+    :param verbose: If true print the result of all files otherwise just failures.
     :returns: None
     """
+    # Get the success, failed and total counts
+    success = len([result.success for result in results if result.success == True])
+    failed = len([result.success for result in results if result.success == False])
+    total = len(results)
+
+    # If the output should not be verbose then only output failures
+    if not verbose:
+        results = [result for result in results if result.success == False]
+
     # Sort based on path length and actual path str ensure files in subfolder
     # is shown before files in additional subfolders
     results.sort(key=lambda r: f"{len(r.filepath.split('/'))} - {r.filepath}")
 
-    success = len([result.success for result in results if result.success == True])
-    failed = len([result.success for result in results if result.success == False])
-
     # Print query by query detail
     print("Dry run results:\n")
     for result in results:
@@ -77,7 +83,7 @@ def output_results(results: List[QueryResult]) -> None:
         print(f"File: {result.filepath}\n  Result: {status}\n  Errors: {errors}\n")
 
     # Print the final result
-    print(f"Total: {len(results)}\nSucceeded: {success}\nFailed: {failed}\n")
+    print(f"Total: {total}\nSucceeded: {success}\nFailed: {failed}\n")
 
 
 def process_args():
@@ -99,6 +105,13 @@ def process_args():
         help="Number of threads for concurrent running of queries. Defaults to 2.",
     )
 
+    parser.add_argument(
+        "-v",
+        "--verbose",
+        action="store_true",
+        help="Show all file results, not just failures.",
+    )
+
     return parser.parse_args()
 
 
@@ -119,7 +132,7 @@ def run():
         for future in concurrent.futures.as_completed(futures):
             results.append(future.result())
 
-    output_results(results)
+    output_results(results, args.verbose)
 
     # Get the status of the overall execution
     status = all([result.success for result in results])
